#!/bin/bash
# Docker镜像加速器配置脚本
# 用于解决从Docker Hub拉取镜像超时的问题

echo "🔧 配置Docker镜像加速器..."

# 创建docker配置目录
sudo mkdir -p /etc/docker

# 备份原有配置（如果存在）
if [ -f /etc/docker/daemon.json ]; then
    sudo cp /etc/docker/daemon.json /etc/docker/daemon.json.backup
    echo "✅ 已备份原有配置文件"
fi

# 配置多个镜像加速器（提高可用性）
cat << 'EOF' | sudo tee /etc/docker/daemon.json
{
  "registry-mirrors": [
    "https://mirror.ccs.tencentyun.com",
    "https://dockerhub.azk8s.cn", 
    "https://reg-mirror.qiniu.com",
    "https://hub-mirror.c.163.com"
  ],
  "exec-opts": ["native.cgroupdriver=systemd"],
  "log-driver": "json-file",
  "log-opts": {
    "max-size": "100m",
    "max-file": "3"
  },
  "storage-driver": "overlay2",
  "insecure-registries": [],
  "live-restore": true
}
EOF

echo "✅ Docker配置文件已更新"

# 重启Docker服务
echo "🔄 重启Docker服务..."
sudo systemctl daemon-reload
sudo systemctl restart docker

# 验证配置
echo "🔍 验证Docker配置..."
sudo systemctl status docker --no-pager -l
docker info | grep -A 10 "Registry Mirrors"

echo "✅ Docker镜像加速器配置完成！"
echo "📝 配置的镜像源："
echo "   - 腾讯云: https://mirror.ccs.tencentyun.com"
echo "   - Azure中国: https://dockerhub.azk8s.cn"
echo "   - 七牛云: https://reg-mirror.qiniu.com"
echo "   - 网易: https://hub-mirror.c.163.com"
